# The Allen SDK

This repository contains code for processing and analyzing data
in the [Allen Brain Atlas](http://brain-map.org/).

Please visit http://alleninstitute.github.io/AllenSDK for more information.

# Authors

Tim Fliss @tfliss
David Feng @dyf

Michael Buice @mabuice
Nicholas Cain @nicain
Werner Van Geit @wvangeit
Richard Gerkin @rgerkin
Nathan Gouwens @gouwens
Nile Graddis
Gabe Ocker
Corinne Teeter
Shreejoy Tripathy @stripathy
Saskia de Vries @saskiad
Derric Williams @derricw

